<?xml version="1.0" ?><!DOCTYPE TS><TS language="gl_ES" version="2.1">
<context>
    <name>CDayMonthView</name>
    <message>
        <source>Monday</source>
        <translation>Luns</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Martes</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Mércores</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Xoves</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Venres</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
</context>
<context>
    <name>CDayWindow</name>
    <message>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
</context>
<context>
    <name>CGraphicsView</name>
    <message>
        <source>New Event</source>
        <translation>Novo evento</translation>
    </message>
</context>
<context>
    <name>CMonthGraphiview</name>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation>Estás eliminando un evento</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>Está seguro de que quere eliminar este evento?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Quere eliminar todas as ocorrencias deste evento, ou só a ocorrencia seleccionada?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Eliminar todo</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Eliminar só este evento</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Quere eliminar esta e todas as ocurrencias futuras deste evento, ou só a ocorrencia seleccionada?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Eliminar todo os eventos futuros</translation>
    </message>
</context>
<context>
    <name>CMonthSchceduleNumButton</name>
    <message>
        <source>%1 more</source>
        <translation>%1 máis</translation>
    </message>
</context>
<context>
    <name>CMonthView</name>
    <message>
        <source>New event</source>
        <translation>Novo evento</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation>Novo evento</translation>
    </message>
</context>
<context>
    <name>CMonthWindow</name>
    <message>
        <source>Y</source>
        <translation>Y</translation>
    </message>
</context>
<context>
    <name>CMySchceduleView</name>
    <message>
        <source>You are deleting an event.</source>
        <translation>Estás eliminando un evento</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>Está seguro de que quere eliminar este evento?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Quere eliminar todas as ocorrencias deste evento, ou só a ocorrencia seleccionada?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Eliminar todo</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Eliminar só este evento</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Quere eliminar esta e todas as ocurrencias futuras deste evento, ou só a ocorrencia seleccionada?</translation>
    </message>
    <message>
        <source>My Event</source>
        <translation>O meu evento</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Eliminar todo os eventos futuros</translation>
    </message>
</context>
<context>
    <name>CSchceduleDlg</name>
    <message>
        <source>New Event</source>
        <translation>Novo evento</translation>
    </message>
    <message>
        <source>Edit Event</source>
        <translation>Editar evento</translation>
    </message>
    <message>
        <source>All occurrences of a repeating event must have the same all-day status.</source>
        <translation>Todas as ocorrencias dun evento que se repite deben ter o mesmo estado durante todo o día.</translation>
    </message>
    <message>
        <source>Do you want to change all occurrences?</source>
        <translation>Quere cambiar todas as ocorrencias?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Change All</source>
        <translation>Cambiar todo</translation>
    </message>
    <message>
        <source>You are changing the repeating rule of this event.</source>
        <translation>Estás a cambiar a regra deste evento.</translation>
    </message>
    <message>
        <source>You are changing a repeating event.</source>
        <translation>Está a cambiar un evento que se repite.</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or all occurrences?</source>
        <translation>Queres cambiar só esta ocorrencia do evento ou todas as ocorrencias?</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Todo</translation>
    </message>
    <message>
        <source>Only This Event</source>
        <translation>Só este evento</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or this and all future occurrences?</source>
        <translation>Quere cambiar só esta ocorrencia do evento, ou esta e todas as futuras ocorrencias?</translation>
    </message>
    <message>
        <source>All Future Events</source>
        <translation>Todos os eventos futuros</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <source>At time of event</source>
        <translation>No momento do evento</translation>
    </message>
    <message>
        <source>15 minutes before</source>
        <translation>15 minutos antes</translation>
    </message>
    <message>
        <source>30 minutes before</source>
        <translation>30 minutos antes</translation>
    </message>
    <message>
        <source>1 hour before</source>
        <translation>1 hora antes</translation>
    </message>
    <message>
        <source>1 day before</source>
        <translation>1 día antes</translation>
    </message>
    <message>
        <source>2 days before</source>
        <translation>2 días antes</translation>
    </message>
    <message>
        <source>1 week before</source>
        <translation>1 semana antes</translation>
    </message>
    <message>
        <source>On start day (9:00 AM)</source>
        <translation>O día de inicio (9:00)</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>All Day:</source>
        <translation>Todo o día:</translation>
    </message>
    <message>
        <source>Remind Me:</source>
        <translation>Recórdame:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>Repetir:</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation>Diariamente</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Días da semana</translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation>Semanalmente</translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation>Mensualmente</translation>
    </message>
    <message>
        <source>Yearly</source>
        <translation>Anualmente</translation>
    </message>
    <message>
        <source>End Repeat:</source>
        <translation>Finalizar a repetición:</translation>
    </message>
    <message>
        <source>After</source>
        <translation>Despois</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Activado</translation>
    </message>
    <message>
        <source>time(s)</source>
        <translation>vez(ces)</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gardar</translation>
    </message>
    <message>
        <source>New event</source>
        <translation>Novo evento</translation>
    </message>
    <message>
        <source>End time must be greater than start time</source>
        <translation>O tempo de finalización debe ser maior que o de inicio</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation>Todo o día</translation>
    </message>
    <message>
        <source>Starts</source>
        <translation>Comeza</translation>
    </message>
    <message>
        <source>Ends</source>
        <translation>Acaba</translation>
    </message>
    <message>
        <source>Remind Me</source>
        <translation>Recórdame</translation>
    </message>
    <message>
        <source>Repeat</source>
        <translation>Repetir</translation>
    </message>
    <message>
        <source>End Repeat</source>
        <translation>Finalizar a repetición:</translation>
    </message>
    <message>
        <source>Ends:</source>
        <translation>Acaba:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descrición:</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrición</translation>
    </message>
    <message>
        <source>Starts:</source>
        <translation>Comeza:</translation>
    </message>
    <message>
        <source>Work</source>
        <translation>Traballo</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Vida</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Outros</translation>
    </message>
</context>
<context>
    <name>CSchceduleSearchDateItem</name>
    <message>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
</context>
<context>
    <name>CSchceduleSearchItem</name>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation>Estás eliminando un evento</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>Está seguro de que quere eliminar este evento?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Quere eliminar todas as ocorrencias deste evento, ou só a ocorrencia seleccionada?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Eliminar todo</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Eliminar só este evento</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Quere eliminar esta e todas as ocurrencias futuras deste evento, ou só a ocorrencia seleccionada?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Eliminar todo os eventos futuros</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation>Todo o día</translation>
    </message>
</context>
<context>
    <name>CSchceduleSearchView</name>
    <message>
        <source>No search results</source>
        <translation>Sen resultados</translation>
    </message>
</context>
<context>
    <name>CScheduleView</name>
    <message>
        <source>ALL DAY</source>
        <translation>Todo o día</translation>
    </message>
</context>
<context>
    <name>CWeekWindow</name>
    <message>
        <source>Week</source>
        <translation>Semana</translation>
    </message>
    <message>
        <source>Y</source>
        <translation>Y</translation>
    </message>
</context>
<context>
    <name>CYearSchceduleItem</name>
    <message>
        <source>All Day</source>
        <translation>Todo o día</translation>
    </message>
</context>
<context>
    <name>CYearSchceduleView</name>
    <message>
        <source>All Day</source>
        <translation>Todo o día</translation>
    </message>
    <message>
        <source>No event</source>
        <translation>Non hai eventos</translation>
    </message>
</context>
<context>
    <name>CYearWindow</name>
    <message>
        <source>Y</source>
        <translation>Y</translation>
    </message>
</context>
<context>
    <name>CalendarWindow</name>
    <message>
        <source>Calendar</source>
        <translation>Calendario</translation>
    </message>
    <message>
        <source>Calendar is a tool to view dates, and also a smart daily planner to schedule all things in life. </source>
        <translation>O calendario é unha ferramenta para ver as datas e tamén un planificador diario intelixente para programar todas as cousas da vida.</translation>
    </message>
</context>
<context>
    <name>Calendarmainwindow</name>
    <message>
        <source>Calendar</source>
        <translation>Calendario</translation>
    </message>
    <message>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
</context>
<context>
    <name>CenterWidget</name>
    <message>
        <source>All Day</source>
        <translation>Todo o día</translation>
    </message>
</context>
<context>
    <name>DragInfoGraphicsView</name>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>New event</source>
        <translation>Novo evento</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation>Estás eliminando un evento</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>Está seguro de que quere eliminar este evento?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Quere eliminar todas as ocorrencias deste evento, ou só a ocorrencia seleccionada?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Eliminar todo</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Eliminar só este evento</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Quere eliminar esta e todas as ocurrencias futuras deste evento, ou só a ocorrencia seleccionada?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Eliminar todo os eventos futuros</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation>Novo evento</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation>Hoxe</translation>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation>Hoxe</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Axuda</translation>
    </message>
    <message>
        <source>Delete event</source>
        <translation>Eliminar evento</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Seleccionar todo</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>YearFrame</name>
    <message>
        <source>Y</source>
        <translation>Y</translation>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation>Hoxe</translation>
    </message>
</context>
</TS>